"""Feed Manager for GDACS feed."""
from typing import Awaitable, Callable, List

from aio_georss_client.feed_manager import FeedManagerBase
from aio_georss_client.status_update import StatusUpdate
from aiohttp import ClientSession

from .feed import GdacsFeed


class GdacsFeedManager(FeedManagerBase):
    """Feed Manager for GDACS feed."""

    def __init__(self,
                 websession: ClientSession,
                 generate_async_callback: Callable[[str], Awaitable[None]],
                 update_async_callback: Callable[[str], Awaitable[None]],
                 remove_async_callback: Callable[[str], Awaitable[None]],
                 coordinates,
                 filter_radius: float = None,
                 filter_categories: List[str] = None,
                 status_async_callback: Callable[[StatusUpdate],
                                                 Awaitable[None]] = None):
        """Initialize the GDACS Feed Manager."""
        feed = GdacsFeed(
            websession,
            coordinates,
            filter_radius=filter_radius,
            filter_categories=filter_categories)
        super().__init__(feed,
                         generate_async_callback,
                         update_async_callback,
                         remove_async_callback,
                         status_async_callback)



"""GDACS constants."""

ATTRIBUTION = "Global Disaster Alert and Coordination System"

XML_ATTRIBUTE_VALUE = "@value"
XML_TEXT = "#text"

XML_TAG_DC_SUBJECT = 'dc:subject'
XML_TAG_GDACS_ALERT_LEVEL = 'gdacs:alertlevel'
XML_TAG_GDACS_COUNTRY = 'gdacs:country'
XML_TAG_GDACS_DURATION_IN_WEEK = 'gdacs:durationinweek'
XML_TAG_GDACS_EVENT_NAME = 'gdacs:eventname'
XML_TAG_GDACS_EVENT_TYPE = 'gdacs:eventtype'
XML_TAG_GDACS_FROM_DATE = 'gdacs:fromdate'
XML_TAG_GDACS_ICON = 'gdacs:icon'
XML_TAG_GDACS_IS_CURRENT = 'gdacs:iscurrent'
XML_TAG_GDACS_POPULATION = 'gdacs:population'
XML_TAG_GDACS_SEVERITY = 'gdacs:severity'
XML_TAG_GDACS_TEMPORARY = 'gdacs:temporary'
XML_TAG_GDACS_TO_DATE = 'gdacs:todate'
XML_TAG_GDACS_VERSION = 'gdacs:version'
XML_TAG_GDACS_VULNERABILITY = 'gdacs:vulnerability'

EVENT_TYPE_MAP = {
    "DR": "Drought",
    "EQ": "Earthquake",
    "FL": "Flood",
    "TC": "Tropical Cyclone",
    "TS": "Tsunami",
    "VO": "Volcano"
}

URL = "https://www.gdacs.org/xml/rss.xml"



import os

from setuptools import setup, find_packages

NAME = "aio_georss_gdacs"
AUTHOR = "Malte Franken"
AUTHOR_EMAIL = "coding@subspace.de"
DESCRIPTION = "An async GeoRSS client library for GDACS feeds."
URL = "https://github.com/exxamalte/python-aio-georss-gdacs"

REQUIRES = [
    'aio_georss_client>=0.4',
    'dateparser>=0.7.0',
]


with open("README.md", "r") as fh:
    long_description = fh.read()

HERE = os.path.abspath(os.path.dirname(__file__))
VERSION = {}
with open(os.path.join(HERE, NAME, "__version__.py")) as f:
    exec(f.read(), VERSION)  # pylint: disable=exec-used

setup(
    name=NAME,
    version=VERSION["__version__"],
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=URL,
    packages=find_packages(exclude=("tests",)),
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    install_requires=REQUIRES
)
